
/********************************************************************************
   * @used    resources:  SPI2 / PB10-15
   * @author  seyed mohammad jafari
   * @version V1.00
   * @date    may-2013
   * @pin     map:  STM32RET6(SPI2)	 NRF24L01
										PB12	->		  CSN
										PB13	->		  SCK
										PB14	<-		  MISO
										PB15	->		  MOSI
										PB11 	<-		  CE
										PB10	<-		  IRQ
		 @breif   
   *******************************************************************************/


#ifndef __NRF24L01_H__
#define __NRF24L01_H__

#include"stm32f10x.h" 
#include"delay/delay.h"

#define NRF24L01_CE_LOW()       GPIO_ResetBits(GPIOB, GPIO_Pin_11)
#define NRF24L01_CE_HIGH()      GPIO_SetBits(GPIOB, GPIO_Pin_11)

#define NRF24L01_CSN_LOW()      GPIO_ResetBits(GPIOB,GPIO_Pin_12);  //NRF24L01 CS enable
#define NRF24L01_CSN_HIGH()     GPIO_SetBits(GPIOB,GPIO_Pin_12);	 //NRF24L01 CS disable

#define NRF24L01_MOSI_LOW()     GPIO_ResetBits(GPIOB, GPIO_Pin_15)
#define NRF24L01_MOSI_HIGH()    GPIO_SetBits(GPIOB, GPIO_Pin_15)

#define NRF24L01_SCK_LOW()      GPIO_ResetBits(GPIOB, GPIO_Pin_13)
#define NRF24L01_SCK_HIGH()     GPIO_SetBits(GPIOB, GPIO_Pin_13)

#define IRQ 					GPIO_ReadInputDataBit(GPIOB, GPIO_Pin_10)	//PB0 IRQ

#define Dummy_Byte   0xff 

//*********************************************NRF24L01*************************************
#define TX_ADR_WIDTH    5   	// 5 uints TX address width
#define RX_ADR_WIDTH    5   	// 5 uints RX address width
#define TX_PLOAD_WIDTH  16  	// 16 uints TX payload
#define RX_PLOAD_WIDTH  16  	// 16 uints TX payload

//***************************************NRF24L01*******************************************************
#define RF_READ_REG        0x00  	
#define RF_WRITE_REG       0x20 	
#define RD_RX_PLOAD     0x61  	
#define WR_TX_PLOAD     0xA0  	
#define FLUSH_TX        0xE1 	
#define FLUSH_RX        0xE2  	
#define REUSE_TX_PL     0xE3  	
#define NOP             0xFF  	
//*************************************SPI(nRF24L01)****************************************************
#define CONFIG          0x00 
#define EN_AA           0x01 
#define EN_RXADDR       0x02 
#define SETUP_AW        0x03  
#define SETUP_RETR      0x04  
#define RF_CH           0x05  
#define RF_SETUP        0x06  
#define STATUS          0x07  
#define OBSERVE_TX      0x08  
#define CD              0x09          
#define RX_ADDR_P0      0x0A 
#define RX_ADDR_P1      0x0B  
#define RX_ADDR_P2      0x0C  
#define RX_ADDR_P3      0x0D  
#define RX_ADDR_P4      0x0E  
#define RX_ADDR_P5      0x0F 
#define TX_ADDR         0x10  
#define RX_PW_P0        0x11 
#define RX_PW_P1        0x12  
#define RX_PW_P2        0x13 
#define RX_PW_P3        0x14  
#define RX_PW_P4        0x15  
#define RX_PW_P5        0x16  
#define FIFO_STATUS     0x17  


u8 SPI_ReadByte(void);
u8 SPI_ReadWrite(u8 writedat);
u8 SPI_Write_Reg(u8 Addr,u8 Value);
u8 SPI_Write_Buf(u8 Addr,u8 *Buffer,u8 Count);
u8 SPI_Read_Reg(u8 Addr);
u8 SPI_Read_Buf(u8 Addr,u8 *Buffer,u8 Count);
void SetRX_Mode(void);
u8 nRF24L01_RxPacket(u8 * rx_buf);
void nRF24L01_TxPacket(u8 * tx_buf);
void NRF24L01_Init(void);
u8 nRF_ready(void);
void  Detect_nrf24l01(void);
void  init_port_nrf24(void);

//		init_port_nrf24();
// 		NRF24L01_Init();                                  
//    Detect_nrf24l01();
//    SetRX_Mode();
//    while(1)
// 	  {
//  		SetRX_Mode();
// 		Delay(10);
// 		LED1_Light;
// 		if(IRQ==0)
// 		{
// 		  if(nRF24L01_RxPacket(RxBuf))
// 		  {
// 		     LED_Flash(100,5);
// 		  }
// 		  else LED1_Disable;
// 		}
// 		
// 	  }




// void nrf_action(void){

// 	u8 RXB,TXB;
// // 	unsigned char Temp1,Temp2;
// 		init_port_nrf24();
// 		NRF24L01_Init();                                  
//    Detect_nrf24l01();
// 	tft_Gotoxy(0, 42);
// 			  tft_Puts("nrf1 connected.", BLACK, WHITE);
//    SetRX_Mode();
// 	tft_Gotoxy(0, 42);
// 			  tft_Puts("nrf1 rx mode ok.", BLACK, WHITE);
// SetRX_Mode();
// 	
// 	init_port_nrf24_2();
// 		NRF24L02_Init();                                  
//    Detect_nrf24l02();
// 	tft_Gotoxy(0, 43);
// 			  tft_Puts("nrf2 connected.", BLACK, WHITE);
// 	tft_Gotoxy(0, 43);
// 			  tft_Puts("nrf2 TX mode ok.", BLACK, WHITE);
// 	
// 	for(i=0;i<20;i++){
// 		TXB=i ;  

// 		nRF24L02_TxPacket(&TXB);
// // 		delay_ms(1000);
// // 		SPI_Read_Reg_2(STATUS);       
// //     SPI_Read_Reg_2(FIFO_STATUS);  

// 		SPI_Write_Reg_2(RF_WRITE_REG+STATUS,0xff); 
// tft_Gotoxy(0, 43);
// 				sprintf(jomle,"data SENT=%u",TXB);
// 			  tft_Puts(jomle, BLACK, WHITE);

// 	



// //   	SetRX_Mode();	
// // 		delay_ms(10);
// 		if(IRQ==0)
// 		{
// 		  if(nRF24L01_RxPacket(&RXB))
// 		  {
// 		     tft_Gotoxy(0, 42);
// 				sprintf(jomle,"data received=%u",RXB);
// 			  tft_Puts(jomle, BLACK, WHITE);
// 		  }
// 		}
// 		
// 	}
// 	
// }

#endif
